@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package CPAN::Meta;
 
-our $VERSION = '2.150004'; # TRIAL
+our $VERSION = '2.150006'; # TRIAL
 
 #pod =head1 SYNOPSIS
 #pod
@@ -650,7 +650,7 @@ CPAN::Meta - the distribution metadata for a CPAN dist
 
 =head1 VERSION
 
-version 2.150004
+version 2.150006
 
 =head1 SYNOPSIS
 
@@ -1035,7 +1035,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Ansgar Burchardt Avar Arnfjord Bjarmason Christopher J. Madsen Chuck Adams Cory G Watson Damyan Ivanov Eric Wilhelm Graham Knop Gregor Hermann Karen Etheridge Kenichi Ishigaki Ken Williams Lars Dieckow Leon Timmermans majensen Mark Fowler Matt S Trout Michael G. Schwern mohawk2 moznion Niko Tyni Olaf Alders Olivier Mengue Randy Sims Tomohiro Hosaka
+=for stopwords Ansgar Burchardt Avar Arnfjord Bjarmason Benjamin Noggle Christopher J. Madsen Chuck Adams Cory G Watson Damyan Ivanov David Golden Eric Wilhelm Graham Knop Gregor Hermann Karen Etheridge Kenichi Ishigaki Kent Fredric Ken Williams Lars Dieckow Leon Timmermans majensen Mark Fowler Matt S Trout Michael G. Schwern mohawk2 moznion Niko Tyni Olaf Alders Olivier Mengué Randy Sims Tomohiro Hosaka
 
 =over 4
 
@@ -1049,6 +1049,10 @@ Avar Arnfjord Bjarmason <avar@cpan.org>
 
 =item *
 
+Benjamin Noggle <agwind@users.noreply.github.com>
+
+=item *
+
 Christopher J. Madsen <cjm@cpan.org>
 
 =item *
@@ -1065,6 +1069,10 @@ Damyan Ivanov <dam@cpan.org>
 
 =item *
 
+David Golden <xdg@xdg.me>
+
+=item *
+
 Eric Wilhelm <ewilhelm@cpan.org>
 
 =item *
@@ -1085,6 +1093,10 @@ Kenichi Ishigaki <ishigaki@cpan.org>
 
 =item *
 
+Kent Fredric <kentfredric@gmail.com>
+
+=item *
+
 Ken Williams <kwilliams@cpan.org>
 
 =item *
@@ -1129,7 +1141,7 @@ Olaf Alders <olaf@wundersolutions.com>
 
 =item *
 
-Olivier Mengue <dolmen@cpan.org>
+Olivier Mengué <dolmen@cpan.org>
 
 =item *
 
