@@ -8,7 +8,7 @@ use strict;
 use warnings;
 package CPAN::Meta::Spec;
 
-our $VERSION = '2.150004'; # TRIAL
+our $VERSION = '2.150006'; # TRIAL
 
 1;
 
@@ -29,7 +29,7 @@ CPAN::Meta::Spec - specification for CPAN distribution metadata
 
 =head1 VERSION
 
-version 2.150004
+version 2.150006
 
 =head1 SYNOPSIS
 
@@ -159,7 +159,8 @@ constraints on the values of a data element.
 =head2 Boolean
 
 A I<Boolean> is used to provide a true or false value.  It B<must> be
-represented as a defined value.
+represented as a defined value that is either "1" or "0" or stringifies
+to those values.
 
 =head2 String
 
@@ -1196,6 +1197,10 @@ L<Module::Build>
 
 L<Module::Install>
 
+=item *
+
+L<CPAN::Meta::History::Meta_1_4>
+
 =back
 
 =head1 HISTORY
